@@ -23,13 +23,12 @@
 
 namespace kt
 {
-
-DBusTorrentFile::DBusTorrentFile(bt::TorrentFileInterface& file, QObject* parent)
-    : QObject(parent), file(file)
+DBusTorrentFile::DBusTorrentFile(bt::TorrentFileInterface &file, QObject *parent)
+    : QObject(parent)
+    , file(file)
 {
 }
 
-
 DBusTorrentFile::~DBusTorrentFile()
 {
 }
