@@ -23,18 +23,16 @@
 
 namespace kt
 {
-
-BWPrefPage::BWPrefPage(QWidget* parent) : PrefPageInterface(SchedulerPluginSettings::self(), i18n("Scheduler"), QStringLiteral("kt-bandwidth-scheduler"), parent)
+BWPrefPage::BWPrefPage(QWidget *parent)
+    : PrefPageInterface(SchedulerPluginSettings::self(), i18n("Scheduler"), QStringLiteral("kt-bandwidth-scheduler"), parent)
 {
     setupUi(this);
 }
 
-
 BWPrefPage::~BWPrefPage()
 {
 }
 
-
 void BWPrefPage::loadDefaults()
 {
     kcfg_screensaverDownloadLimit->setEnabled(SchedulerPluginSettings::screensaverLimits());
