@@ -23,21 +23,20 @@
 
 #include <cmath>
 
-#include <QApplication>
 #include <KLocalizedString>
+#include <QApplication>
 
-#include <util/functions.h>
-#include <interfaces/functions.h>
-#include <interfaces/torrentinterface.h>
-#include <interfaces/torrentfileinterface.h>
 #include "infowidgetpluginsettings.h"
+#include <interfaces/functions.h>
+#include <interfaces/torrentfileinterface.h>
+#include <interfaces/torrentinterface.h>
+#include <util/functions.h>
 
 using namespace bt;
 
 namespace kt
 {
-
-IWFileTreeModel::IWFileTreeModel(bt::TorrentInterface* tc, QObject* parent)
+IWFileTreeModel::IWFileTreeModel(bt::TorrentInterface *tc, QObject *parent)
     : TorrentFileTreeModel(tc, KEEP_FILES, parent)
 {
     mmfile = tc ? IsMultimediaFile(tc->getStats().output_path) : 0;
@@ -51,12 +50,11 @@ IWFileTreeModel::IWFileTreeModel(bt::TorrentInterface* tc, QObject* parent)
     }
 }
 
-
 IWFileTreeModel::~IWFileTreeModel()
 {
 }
 
-void IWFileTreeModel::changeTorrent(bt::TorrentInterface* tc)
+void IWFileTreeModel::changeTorrent(bt::TorrentInterface *tc)
 {
     kt::TorrentFileTreeModel::changeTorrent(tc);
     mmfile = tc ? IsMultimediaFile(tc->getStats().output_path) : 0;
@@ -70,8 +68,7 @@ void IWFileTreeModel::changeTorrent(bt::TorrentInterface* tc)
     }
 }
 
-
-int IWFileTreeModel::columnCount(const QModelIndex& /*parent*/) const
+int IWFileTreeModel::columnCount(const QModelIndex & /*parent*/) const
 {
     return 5;
 }
@@ -85,38 +82,45 @@ QVariant IWFileTreeModel::headerData(int section, Qt::Orientation orientation, i
         return TorrentFileTreeModel::headerData(section, orientation, role);
 
     switch (section) {
-    case 2: return i18n("Priority");
-    case 3: return i18nc("@title:column", "Preview");
+    case 2:
+        return i18n("Priority");
+    case 3:
+        return i18nc("@title:column", "Preview");
     // xgettext: no-c-format
-    case 4: return i18nc("Percent of File Downloaded", "% Complete");
-    default: return QVariant();
+    case 4:
+        return i18nc("Percent of File Downloaded", "% Complete");
+    default:
+        return QVariant();
     }
 }
 
-static QString PriorityString(const bt::TorrentFileInterface* file)
+static QString PriorityString(const bt::TorrentFileInterface *file)
 {
     switch (file->getPriority()) {
-    case FIRST_PRIORITY: return i18nc("Download first", "First");
-    case LAST_PRIORITY: return i18nc("Download last", "Last");
+    case FIRST_PRIORITY:
+        return i18nc("Download first", "First");
+    case LAST_PRIORITY:
+        return i18nc("Download last", "Last");
     case ONLY_SEED_PRIORITY:
     case EXCLUDED:
     case PREVIEW_PRIORITY:
         return QString();
-    default: return i18nc("Download normally(not as first or last)", "Normal");
+    default:
+        return i18nc("Download normally(not as first or last)", "Normal");
     }
 }
 
-QVariant IWFileTreeModel::data(const QModelIndex& index, int role) const
+QVariant IWFileTreeModel::data(const QModelIndex &index, int role) const
 {
-    Node* n = 0;
+    Node *n = 0;
     if (index.column() < 2 && role != Qt::ForegroundRole)
         return TorrentFileTreeModel::data(index, role);
 
-    if (!tc || !index.isValid() || !(n = (Node*)index.internalPointer()))
+    if (!tc || !index.isValid() || !(n = (Node *)index.internalPointer()))
         return QVariant();
 
     if (role == Qt::ForegroundRole && index.column() == 2 && tc->getStats().multi_file_torrent && n->file) {
-        const bt::TorrentFileInterface* file = n->file;
+        const bt::TorrentFileInterface *file = n->file;
         switch (file->getPriority()) {
         case FIRST_PRIORITY:
             return InfoWidgetPluginSettings::firstColor();
@@ -140,12 +144,13 @@ QVariant IWFileTreeModel::data(const QModelIndex& index, int role) const
     return QVariant();
 }
 
-QVariant IWFileTreeModel::displayData(Node* n, const QModelIndex& index) const
+QVariant IWFileTreeModel::displayData(Node *n, const QModelIndex &index) const
 {
     if (tc->getStats().multi_file_torrent && n->file) {
-        const bt::TorrentFileInterface* file = n->file;
+        const bt::TorrentFileInterface *file = n->file;
         switch (index.column()) {
-        case 2: return PriorityString(file);
+        case 2:
+            return PriorityString(file);
         case 3:
             if (file->isMultimedia()) {
                 if (file->isPreviewAvailable())
@@ -159,11 +164,13 @@ QVariant IWFileTreeModel::displayData(Node* n, const QModelIndex& index) const
                 return QVariant();
             else
                 return ki18n("%1 %").subs(n->percentage, 0, 'f', 2).toString();
-        default: return QVariant();
+        default:
+            return QVariant();
         }
     } else if (!tc->getStats().multi_file_torrent) {
         switch (index.column()) {
-        case 2: return QVariant();
+        case 2:
+            return QVariant();
         case 3:
             if (mmfile) {
                 if (tc->readyForPreview())
@@ -174,7 +181,8 @@ QVariant IWFileTreeModel::displayData(Node* n, const QModelIndex& index) const
                 return i18nc("No preview available", "No");
         case 4:
             return ki18n("%1 %").subs(bt::Percentage(tc->getStats()), 0, 'f', 2).toString();
-        default: return QVariant();
+        default:
+            return QVariant();
         }
     } else if (tc->getStats().multi_file_torrent && index.column() == 4) {
         return ki18n("%1 %").subs(n->percentage, 0, 'f', 2).toString();
@@ -183,12 +191,13 @@ QVariant IWFileTreeModel::displayData(Node* n, const QModelIndex& index) const
     return QVariant();
 }
 
-QVariant IWFileTreeModel::sortData(Node* n, const QModelIndex& index) const
+QVariant IWFileTreeModel::sortData(Node *n, const QModelIndex &index) const
 {
     if (tc->getStats().multi_file_torrent && n->file) {
-        const bt::TorrentFileInterface* file = n->file;
+        const bt::TorrentFileInterface *file = n->file;
         switch (index.column()) {
-        case 2: return (int)file->getPriority();
+        case 2:
+            return (int)file->getPriority();
         case 3:
             if (file->isMultimedia()) {
                 if (file->isPreviewAvailable())
@@ -202,7 +211,8 @@ QVariant IWFileTreeModel::sortData(Node* n, const QModelIndex& index) const
         }
     } else if (!tc->getStats().multi_file_torrent) {
         switch (index.column()) {
-        case 2: return QVariant();
+        case 2:
+            return QVariant();
         case 3:
             if (mmfile) {
                 if (tc->readyForPreview())
@@ -221,19 +231,19 @@ QVariant IWFileTreeModel::sortData(Node* n, const QModelIndex& index) const
     return QVariant();
 }
 
-void IWFileTreeModel::changePriority(const QModelIndexList& indexes, Priority newpriority)
+void IWFileTreeModel::changePriority(const QModelIndexList &indexes, Priority newpriority)
 {
     if (!tc)
         return;
 
-    for (const QModelIndex& idx : indexes) {
-        Node* n = (Node*)idx.internalPointer();
+    for (const QModelIndex &idx : indexes) {
+        Node *n = (Node *)idx.internalPointer();
         if (n)
             setPriority(n, newpriority, true);
     }
 }
 
-void IWFileTreeModel::setPriority(TorrentFileTreeModel::Node* n, Priority newpriority, bool selected_node)
+void IWFileTreeModel::setPriority(TorrentFileTreeModel::Node *n, Priority newpriority, bool selected_node)
 {
     if (!n->file) {
         for (int i = 0; i < n->children.count(); i++) {
@@ -243,7 +253,7 @@ void IWFileTreeModel::setPriority(TorrentFileTreeModel::Node* n, Priority newpri
 
         Q_EMIT dataChanged(createIndex(n->row(), 0, n), createIndex(n->row(), 4, n));
     } else {
-        bt::TorrentFileInterface* file = n->file;
+        bt::TorrentFileInterface *file = n->file;
         Priority old = file->getPriority();
 
         // When recursing down the tree don't reinclude files
@@ -257,26 +267,26 @@ void IWFileTreeModel::setPriority(TorrentFileTreeModel::Node* n, Priority newpri
     }
 }
 
-void IWFileTreeModel::filePercentageChanged(bt::TorrentFileInterface* file, float percentage)
+void IWFileTreeModel::filePercentageChanged(bt::TorrentFileInterface *file, float percentage)
 {
     Q_UNUSED(percentage);
     if (tc)
         update(index(0, 0, QModelIndex()), file, 4);
 }
 
-void IWFileTreeModel::filePreviewChanged(bt::TorrentFileInterface* file, bool preview)
+void IWFileTreeModel::filePreviewChanged(bt::TorrentFileInterface *file, bool preview)
 {
     Q_UNUSED(preview);
     if (tc)
         update(index(0, 0, QModelIndex()), file, 3);
 }
 
-void IWFileTreeModel::update(const QModelIndex& idx, bt::TorrentFileInterface* file, int col)
+void IWFileTreeModel::update(const QModelIndex &idx, bt::TorrentFileInterface *file, int col)
 {
     if (!tc)
         return;
 
-    Node* n = (Node*)idx.internalPointer();
+    Node *n = (Node *)idx.internalPointer();
     if (n->file && n->file == file) {
         QModelIndex i = createIndex(idx.row(), col, n);
         Q_EMIT dataChanged(i, i);
@@ -291,7 +301,7 @@ void IWFileTreeModel::update(const QModelIndex& idx, bt::TorrentFileInterface* f
             // emit necessary signals
             QModelIndex parent = idx.parent();
             while (parent.isValid()) {
-                Node* nd = (Node*)parent.internalPointer();
+                Node *nd = (Node *)parent.internalPointer();
                 i = createIndex(parent.row(), 4, nd);
                 Q_EMIT dataChanged(i, i);
                 parent = parent.parent();
@@ -329,4 +339,3 @@ void IWFileTreeModel::update()
     }
 }
 }
-
