@@ -22,23 +22,20 @@
 #ifndef KTVIDEOWIDGET_H
 #define KTVIDEOWIDGET_H
 
-#include <QAction>
-#include <QWidget>
-#include <Phonon/VideoWidget>
 #include <Phonon/MediaObject>
 #include <Phonon/SeekSlider>
+#include <Phonon/VideoWidget>
 #include <Phonon/VolumeSlider>
+#include <QAction>
+#include <QWidget>
 
 class QAction;
-class QDBusInterface;
 class QLabel;
-class QStackedWidget;
 class KToolBar;
 class KActionCollection;
 
 namespace kt
 {
-
 class VideoChunkBar;
 class MediaPlayer;
 class MediaFileRef;
@@ -46,12 +43,12 @@ class MediaFileRef;
 /**
  * Widget to display a video
  * @author Joris Guisson
-*/
+ */
 class VideoWidget : public QWidget
 {
     Q_OBJECT
 public:
-    VideoWidget(MediaPlayer* player, KActionCollection* ac, QWidget* parent);
+    VideoWidget(MediaPlayer *player, KActionCollection *ac, QWidget *parent);
     ~VideoWidget() override;
 
     /**
@@ -61,15 +58,15 @@ public:
     void setFullScreen(bool on);
 
 protected:
-    void mouseMoveEvent(QMouseEvent* event) override;
-    bool eventFilter(QObject* dst, QEvent* event) override;
+    void mouseMoveEvent(QMouseEvent *event) override;
+    bool eventFilter(QObject *dst, QEvent *event) override;
 
 private Q_SLOTS:
     void play();
     void stop();
     void setControlsVisible(bool on);
     void timerTick(qint64 time);
-    void playing(const MediaFileRef& mfile);
+    void playing(const MediaFileRef &mfile);
     void enableActions(unsigned int flags);
 
 Q_SIGNALS:
@@ -80,15 +77,15 @@ private:
     QString formatTime(qint64 cur, qint64 total);
 
 private:
-    Phonon::VideoWidget* video;
-    MediaPlayer* player;
-    Phonon::SeekSlider* slider;
-    KToolBar* tb;
-    QAction * play_action;
-    QAction * stop_action;
-    QLabel* time_label;
-    Phonon::VolumeSlider* volume;
-    VideoChunkBar* chunk_bar;
+    Phonon::VideoWidget *video;
+    MediaPlayer *player;
+    Phonon::SeekSlider *slider;
+    KToolBar *tb;
+    QAction *play_action;
+    QAction *stop_action;
+    QLabel *time_label;
+    Phonon::VolumeSlider *volume;
+    VideoChunkBar *chunk_bar;
     bool fullscreen;
     quint32 screensaver_cookie;
     quint32 powermanagement_cookie;
